@@ -3,25 +3,30 @@ if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
 fi
 
-( cd usr/share/doc/HTML/en/kfilereplace ; rm -rf common )
-( cd usr/share/doc/HTML/en/kfilereplace ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/klinkstatus ; rm -rf common )
-( cd usr/share/doc/HTML/en/klinkstatus ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/share/doc/HTML/en/kimagemapeditor ; rm -rf common )
-( cd usr/share/doc/HTML/en/kimagemapeditor ; ln -sf /usr/share/doc/HTML/en/common common )
-( cd usr/lib ; rm -rf libkommandercore.so.4 )
-( cd usr/lib ; ln -sf libkommandercore.so.4.2.0 libkommandercore.so.4 )
-( cd usr/lib ; rm -rf libkommanderwidgets.so.4 )
-( cd usr/lib ; ln -sf libkommanderwidgets.so.4.2.0 libkommanderwidgets.so.4 )
-( cd usr/lib ; rm -rf libtidy-0.99.so.0 )
-( cd usr/lib ; ln -sf libtidy-0.99.so.0.0.0 libtidy-0.99.so.0 )
-( cd usr/lib ; rm -rf libklinkstatuscommon.so )
-( cd usr/lib ; ln -sf libklinkstatuscommon.so.4 libklinkstatuscommon.so )
-( cd usr/lib ; rm -rf libklinkstatuscommon.so.4 )
-( cd usr/lib ; ln -sf libklinkstatuscommon.so.4.0.0 libklinkstatuscommon.so.4 )
-( cd usr/lib ; rm -rf libkommanderwidgets.so )
-( cd usr/lib ; ln -sf libkommanderwidgets.so.4 libkommanderwidgets.so )
 ( cd usr/lib ; rm -rf libtidy.so )
 ( cd usr/lib ; ln -sf libtidy-0.99.so.0.0.0 libtidy.so )
+( cd usr/lib ; rm -rf libklinkstatuscommon.so.4 )
+( cd usr/lib ; ln -sf libklinkstatuscommon.so.4.0.0 libklinkstatuscommon.so.4 )
+( cd usr/lib ; rm -rf libtidy-0.99.so.0 )
+( cd usr/lib ; ln -sf libtidy-0.99.so.0.0.0 libtidy-0.99.so.0 )
+( cd usr/lib ; rm -rf libkommanderwidgets.so )
+( cd usr/lib ; ln -sf libkommanderwidgets.so.4 libkommanderwidgets.so )
+( cd usr/lib ; rm -rf libkommandercore.so.4 )
+( cd usr/lib ; ln -sf libkommandercore.so.4.2.0 libkommandercore.so.4 )
 ( cd usr/lib ; rm -rf libkommandercore.so )
 ( cd usr/lib ; ln -sf libkommandercore.so.4 libkommandercore.so )
+( cd usr/lib ; rm -rf libklinkstatuscommon.so )
+( cd usr/lib ; ln -sf libklinkstatuscommon.so.4 libklinkstatuscommon.so )
+( cd usr/lib ; rm -rf libkommanderwidgets.so.4 )
+( cd usr/lib ; ln -sf libkommanderwidgets.so.4.2.0 libkommanderwidgets.so.4 )
+( cd usr/doc/HTML/en/kfilereplace ; rm -rf common )
+( cd usr/doc/HTML/en/kfilereplace ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/doc/HTML/en/kimagemapeditor ; rm -rf common )
+( cd usr/doc/HTML/en/kimagemapeditor ; ln -sf /usr/share/doc/HTML/en/common common )
+( cd usr/doc/HTML/en/klinkstatus ; rm -rf common )
+( cd usr/doc/HTML/en/klinkstatus ; ln -sf /usr/share/doc/HTML/en/common common )
+
+if [ -x /usr/bin/update-desktop-database ]; then
+  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
+fi
+
